import { MonitorCollection, Monitor, CheckCollection, QueryCollection } from './model';
export type Caller = {
    call(method: string, resource: string, path: string, body: string | undefined, pathParameters: Record<string, string>, queryParameters: Record<string, string>, multiQueryParameters: Record<string, string[]>, headers: Record<string, string>, config?: Record<string, string>): Promise<{
        statusCode: number;
        body: string;
        headers: Record<string, string>;
    }>;
};
export declare class PostgresCheckApiSdk {
    private readonly caller;
    constructor(caller: Caller);
    getMonitors(headers?: Record<string, string>, config?: Record<string, any>): Promise<({
        statusCode: 200;
        result: MonitorCollection;
    } | {
        statusCode: 400;
        result: string;
    } | {
        statusCode: 401;
        result: string;
    } | {
        statusCode: 403;
        result: string;
    } | {
        statusCode: 500;
        result: string;
    }) & {
        headers: Record<string, string>;
    }>;
    createMonitor(body: Monitor, headers?: Record<string, string>, config?: Record<string, any>): Promise<({
        statusCode: 201;
        result: Monitor;
    } | {
        statusCode: 400;
        result: string;
    } | {
        statusCode: 401;
        result: string;
    } | {
        statusCode: 403;
        result: string;
    } | {
        statusCode: 500;
        result: string;
    }) & {
        headers: Record<string, string>;
    }>;
    getChecks(params: {
        monitorId: string;
    }, queryParameters: {
        created?: string;
        limit?: string;
        next?: string;
    }, multiQueryParameters: {
        created?: string[];
        limit?: string[];
        next?: string[];
    }, headers?: Record<string, string>, config?: Record<string, any>): Promise<({
        statusCode: 200;
        result: CheckCollection;
    } | {
        statusCode: 400;
        result: string;
    } | {
        statusCode: 401;
        result: string;
    } | {
        statusCode: 403;
        result: string;
    } | {
        statusCode: 500;
        result: string;
    }) & {
        headers: Record<string, string>;
    }>;
    getQueries(params: {
        monitorId: string;
        checkId: string;
    }, queryParameters: {
        type?: string;
        created?: string;
        limit?: string;
        next?: string;
    }, multiQueryParameters: {
        type?: string[];
        created?: string[];
        limit?: string[];
        next?: string[];
    }, headers?: Record<string, string>, config?: Record<string, any>): Promise<({
        statusCode: 200;
        result: QueryCollection;
    } | {
        statusCode: 400;
        result: string;
    } | {
        statusCode: 401;
        result: string;
    } | {
        statusCode: 403;
        result: string;
    } | {
        statusCode: 500;
        result: string;
    }) & {
        headers: Record<string, string>;
    }>;
}
export * from './model.js';
