resource "aws_iam_role" "lambda_role" {
  name               = "postgres-check-api-lambda-role"
  assume_role_policy = jsonencode({
    "Version" : "2012-10-17",
    "Statement" : [
      {
        "Action" : "sts:AssumeRole",
        "Principal" : {
          "Service" : "lambda.amazonaws.com"
        },
        "Effect" : "Allow"
      }
    ]
  })
}

resource "aws_iam_policy" "lambda_policy" {
  name   = "postgres-check-api-lambda-policy"
  path   = "/"
  policy = jsonencode(
    {
      "Version" : "2012-10-17",
      "Statement" : [
        {
          "Action" : [
            "logs:CreateLogGroup",
            "logs:CreateLogStream",
            "logs:PutLogEvents"
          ],
          "Resource" : "arn:aws:logs:*:*:*",
          "Effect" : "Allow"
        },
        {
          "Action" : [
            "dynamodb:*"
          ],
          "Resource" : [
            "arn:aws:dynamodb:eu-west-1:211125682198:table/postgres-check",
            "arn:aws:dynamodb:eu-west-1:211125682198:table/postgres-check/*"
          ],
          "Effect" : "Allow"
        }
      ]
    })
}

resource "aws_iam_role_policy_attachment" "lambda_role_policy_attachment" {
  role       = aws_iam_role.lambda_role.name
  policy_arn = aws_iam_policy.lambda_policy.arn
}

data "archive_file" "lambda_code" {
  type        = "zip"
  source_dir  = "${path.module}/../build/"
  output_path = "${path.module}/lambda-code.zip"
}

resource "aws_lambda_function" "lambda_function" {
  filename         = data.archive_file.lambda_code.output_path
  function_name    = "postgres-check-api-lambda"
  role             = aws_iam_role.lambda_role.arn
  handler          = "index.handler"
  runtime          = "nodejs20.x"
  depends_on       = [aws_iam_role_policy_attachment.lambda_role_policy_attachment, data.archive_file.lambda_code]
  source_code_hash = data.archive_file.lambda_code.output_base64sha256
}