import { APIGatewayProxyEvent } from 'aws-lambda/trigger/api-gateway-proxy';
import { CheckDatabaseService } from '../service/CheckDatabaseService';
import { Account } from '../../generated/postgres-check-api/model';

export class CheckController {
  constructor(private checkDatabaseService: CheckDatabaseService) {}

  async getChecks(account: Account, event: APIGatewayProxyEvent) {
    const { monitorId } = event.pathParameters;
    const { created, limit, next } = event.queryStringParameters ?? {};
    if (!created) {
      return {
        statusCode: 400,
        body: JSON.stringify({ message: 'Bad Request' }),
      };
    }
    const checkCollection = await this.checkDatabaseService.getChecks(
      account,
      monitorId,
      created,
      limit,
      next,
    );
    return { statusCode: 200, body: JSON.stringify(checkCollection) };
  }
}
