import { APIGatewayProxyEvent } from 'aws-lambda/trigger/api-gateway-proxy';
import { QueryDatabaseService } from '../service/QueryDatabaseService';
import { Account } from '../../generated/postgres-check-api/model';

export class QueryController {
  constructor(private queryDatabaseService: QueryDatabaseService) {}

  async getQueries(account: Account, event: APIGatewayProxyEvent) {
    const { monitorId, checkId } = event.pathParameters;
    const { created, limit, next, type } = event.queryStringParameters ?? {};
    if (!created) {
      return {
        statusCode: 400,
        body: JSON.stringify({ message: 'Bad Request' }),
      };
    }
    const queryCollection = await this.queryDatabaseService.getQueries(
      account,
      monitorId,
      checkId,
      created,
      limit,
      next,
      type,
    );
    return { statusCode: 200, body: JSON.stringify(queryCollection) };
  }
}
