import { DynamoDBDocument } from '@aws-sdk/lib-dynamodb';
import { TableClient } from '@hexlabs/dynamo-ts';
import { monitorTable } from '../../tables';
import { Monitor } from '../../../generated/postgres-check-api/model';

export class MonitorCommandDatabase {
  constructor(
    documentClient: DynamoDBDocument,
    private monitorTableClient = TableClient.build(monitorTable, {
      tableName: 'postgres-check',
      client: documentClient,
      logStatements: false,
    }),
  ) {}

  async createMonitor(monitor: Monitor): Promise<Monitor> {
    try {
      console.log('Creating monitor in database');

      await this.monitorTableClient.put({
        partitionKey: `#ACCOUNT-${monitor.account}`,
        sortKey: `${monitor.created}#MONITOR-${monitor.id}`,
        ...monitor,
      });

      console.log('Created monitor in database');

      return monitor;
    } catch (error) {
      console.error('Creating monitor in database failed', error);
    }
  }
}
