import {
  Account,
  Query,
  QueryCollection,
} from '../../../generated/postgres-check-api/model';
import { DynamoDBDocument } from '@aws-sdk/lib-dynamodb';
import { TableClient } from '@hexlabs/dynamo-ts';
import { queryTable } from '../../tables';

export class QueryQueryDatabase {
  constructor(
    documentClient: DynamoDBDocument,
    private queryTableClient = TableClient.build(queryTable, {
      tableName: 'postgres-check',
      client: documentClient,
      logStatements: false,
    }),
  ) {}

  async getQueries(
    account: Account,
    checkId: string,
    date: string,
    next?: string,
    type?: string,
  ): Promise<QueryCollection> {
    try {
      console.log('Getting queries from database');
      const {
        next: viewNext,
        member,
        count,
      } = await this.queryTableClient.query<Query>(
        { partitionKey: `#ACCOUNT-${account.email}#CHECK-${checkId}#${date}` },
        {
          next: next,
          ...(type ? { filter: (compare) => compare().type.eq(type) } : {}),
        },
      );
      console.log('Got queries from database');
      return {
        member: member,
        totalItems: count,
        view: viewNext ? { next: viewNext } : undefined,
      };
    } catch (error) {
      console.error('Getting queries from database failed', error);
    }
  }
}
