import {
  Account,
  Check,
  CheckCollection,
} from '../../generated/postgres-check-api/model';
import { CheckQueryDatabase } from '../database/query/CheckQueryDatabase';

export class CheckDatabaseService {
  constructor(private checkQueryDatabase: CheckQueryDatabase) {}

  async getChecks(
    account: Account,
    monitorId: string,
    date: string,
    queryLimit: string,
    next: string,
  ): Promise<CheckCollection> {
    try {
      console.log('Getting checks');

      const limit = queryLimit ? parseInt(queryLimit) : 100;
      const checks = [];
      let response = await this.checkQueryDatabase.getChecks(
        account,
        monitorId,
        date,
        next,
      );

      if (response.member) {
        checks.push(...response.member);
      }
      while (checks.length < limit && response.view) {
        response = await this.checkQueryDatabase.getChecks(
          account,
          monitorId,
          date,
          next,
        );
        if (response.member) {
          checks.push(...response.member);
        }
      }
      const member = checks.slice(0, limit);
      const last = member[member.length - 1];
      console.log('Got checks');
      return {
        member: member,
        totalItems: member.length,
        view:
          member.length < checks.length
            ? {
                next: Buffer.from(
                  JSON.stringify({
                    partitionKey: `#MONITOR-${monitorId}#${date}`,
                    sortKey: last.sortKey,
                  }),
                ).toString('base64'),
              }
            : response.view
              ? { next: response.view.next }
              : undefined,
      };
    } catch (error) {
      console.error('Getting checks failed', error);
    }
  }
}
