import { MonitorQueryDatabase } from '../database/query/MonitorQueryDatabase';
import {
  Account,
  Monitor,
  MonitorCollection,
} from '../../generated/postgres-check-api/model';
import { MonitorCommandDatabase } from '../database/command/MonitorCommandDatabase';
import { v4 as uuidv4 } from 'uuid';

export class MonitorDatabaseService {
  constructor(
    private monitorCommandDatabase: MonitorCommandDatabase,
    private monitorQueryDatabase: MonitorQueryDatabase,
  ) {}

  async createMonitor(
    account: Account,
    monitor: Monitor,
  ): Promise<Monitor | undefined> {
    try {
      console.log('Creating monitor', monitor);

      const createMonitor: Monitor = {
        id: uuidv4(),
        created: new Date().toISOString(),
        account: account.email,
        name: monitor.name,
        connectionString: monitor.connectionString,
      };
      const createdMonitor =
        await this.monitorCommandDatabase.createMonitor(createMonitor);

      console.log('Created monitor', createdMonitor);
      return createdMonitor;
    } catch (error) {
      console.error('Creating monitors failed', error);
      return undefined;
    }
  }

  async getMonitors(account: Account): Promise<MonitorCollection> {
    try {
      console.log('Getting monitors for account', account);

      const monitorCollection =
        await this.monitorQueryDatabase.getMonitors(account);

      console.log('Got monitors');
      return monitorCollection;
    } catch (error) {
      console.error('Getting monitors failed', account, error);
    }
  }
}
