import {
  Account,
  Query,
  QueryCollection,
} from '../../generated/postgres-check-api/model';
import { QueryQueryDatabase } from '../database/query/QueryQueryDatabase';

export class QueryDatabaseService {
  constructor(private queryQueryDatabase: QueryQueryDatabase) {}

  async getQueries(
    account: Account,
    monitorId: string,
    checkId: string,
    date: string,
    queryLimit: string,
    next: string,
    type: string,
  ): Promise<QueryCollection> {
    try {
      console.log('Getting queries');

      const limit = queryLimit ? parseInt(queryLimit) : 100;
      const queries = [];
      let response = await this.queryQueryDatabase.getQueries(
        account,
        checkId,
        date,
        next,
        type,
      );

      if (response.member) {
        queries.push(...response.member);
      }
      while (queries.length < limit && response.view) {
        response = await this.queryQueryDatabase.getQueries(
          account,
          monitorId,
          date,
          next,
          type,
        );
        if (response.member) {
          queries.push(...response.member);
        }
      }
      const member = queries.slice(0, limit);
      const last = member[member.length - 1];

      console.log('Got queries');
      return {
        member: member,
        totalItems: member.length,
        view:
          member.length < queries.length
            ? {
                next: Buffer.from(
                  JSON.stringify({
                    partitionKey: `#CHECK-${checkId}#${date}`,
                    sortKey: last.sortKey,
                  }),
                ).toString('base64'),
              }
            : response.view
              ? { next: response.view.next }
              : undefined,
      };
    } catch (error) {
      console.error('Getting queries failed', error);
    }
  }
}
